@@ -152,15 +152,16 @@ cmap.
 sub update
 {
     my ($self) = @_;
-    my ($map, $temp);
+    my ($map, @keys);
 
     return undef unless $self->{' PARENT'}{'cmap'}{' isDirty'};
     $self->{' PARENT'}{'cmap'}->update;
     $map = $self->{' PARENT'}{'cmap'}->find_ms || return undef;
 
-    $self->{'usFirstCharIndex'} = $map->{'val'}[0]->{'START'};
-    $temp = $map->{'val'}[$#{$map->{'val'}} - 1];
-    $self->{'usLastCharIndex'} = $temp->{'START'} + $temp->{'LEN'} - 1;
+    @keys = sort {$a <=> $b} keys %{$map->{'val'}};
+
+    $self->{'usFirstCharIndex'} = $keys[0];
+    $self->{'usLastCharIndex'} = $keys[-1];
     $self;
 }
 
@@ -172,7 +173,7 @@ None known
 
 =head1 AUTHOR
 
-Martin Hosken L<Martin_Hosken@sil.org>. See L<Font::TTF::Font> for copyright and
+Martin Hosken Martin_Hosken@sil.org. See L<Font::TTF::Font> for copyright and
 licensing.
 
 =cut
