@@ -241,13 +241,17 @@ sub out
 
 =head1 BUGS
 
+=over 4
+
 =item *
 
 No support for type 4 tables
 
+=back
+
 =head1 AUTHOR
 
-Martin Hosken L<Martin_Hosken@sil.org>. See L<Font::TTF::Font> for copyright and
+Martin Hosken Martin_Hosken@sil.org. See L<Font::TTF::Font> for copyright and
 licensing.
 
 =cut
@@ -418,7 +422,7 @@ mu1
 partialdiff
 summation
 product
-mu
+pi
 integral
 ordfeminine
 ordmasculine
